==> glark-1.6.5.tar.gz: glark-1.6.5/glarkrun.rb <==
#!/bin/sh
exec ruby -w -x $0 ${1+"$@"} # -*- ruby -*-
#!ruby -w

# An extended grep, with extended functionality including full regular
# expressions, contextual output, highlighting, detection and exclusion of
# nontext files, and complex matching criteria.

# $Id: glarkrun.rb,v 1.9 2003/08/20 15:12:06 jeugenepace Exp $

require "English"

$stdout.sync = true             # unbuffer
$stderr.sync = true             # unbuffer

$PACKAGE = "glark"
$VERSION = "1.6.5"

require './glarkfile'
require './filetester'

# The main processor.
class Glark 
  include Log
  
  def initialize(func)
    @func = func
  end

  def search_file(fname, lines)
    log "searching #{fname} for #{@func}" if $options.verbose
    p = InputFile.new(fname, lines)
    @func.process(p)
  end

  def search_binary_file(fname, lines)
    log "searching binary file #{fname} for #{@func}" if $options.verbose
    bf = BinaryFile.new(fname, lines)
    @func.process(bf)
  end
  
  def search(name)
    log "searching #{name} for #{@func}"

    if name == "-" 
      log "reading standard input..."
      $stderr.print "reading standard input...\n" unless $options.quiet
      search_file(name, $stdin.readlines)
    else
      type = FileTester.type(name)
      case type
      when FileTester::TEXT
        log "searching text"
        search_file(name, IO.readlines(name))
      when FileTester::BINARY
        log "handling binary"
        # Log.print "not a text file: #{name}\n"
        
        case $options.binary_files
        when "without-match"
          log "skipping binary file #{name}"
          
        when "binary"
          search_binary_file(name, IO.readlines(name))
          
        when "text"
          log "processing binary file #{name} as text"
          search_file(name, IO.readlines(name))
        end
        
      when FileTester::UNREADABLE
        log "skipping unreadable"
        $stderr.print "file not readable: #{name}\n" unless $options.quiet
      when FileTester::NONE
        log "skipping none"
        $stderr.print "WARNING: no such file: #{name}\n" unless $options.quiet
      when FileTester::UNKNOWN
        log "skipping unknown"
        $stderr.print "WARNING: unknown file type: #{name}\n" unless $options.quiet
      when FileTester::DIRECTORY
        log "processing directory"
        case $options.directory
        when "read"
          $stderr.print "glark: #{name}: Is a directory\n" unless $options.quiet
        when "recurse"
          entries = Dir.entries(name).reject { |x| x == "." || x == ".." }
          entries.each do |e|
            search(name + "/" + e)
          end
        when "skip"
          Log.print "skipping directory #{name}"
        end
      else
        print "unknown type #{type}"
      end
    end
  end
end

require './glarkopt'

begin
  Log.set_widths(15, 5, -30)
  Log.set_color(Log::DEBUG, "reverse")

  Log.log "loading options"
  GlarkOptions.new($PACKAGE, $VERSION).run
  Log.log "done loading options"

  # To get rid of the annoying stack trace on ctrl-C:
  trap("INT") { abort }

  puts $options.expr if $options.explain

  glark = Glark.new($options.expr)
  files = if ARGV.size > 0 then ARGV else [ '-' ] end

  files.each do |f|
    if $options.exclude_matching_files
      if $options.expr.evaluate(f, 0, 0)
        Log.log "skipping file #{f} with matching name"
        next
      else
        Log.log "not skipping file #{f}"
      end
    end
    glark.search(f) 
  end
rescue => e
  # show only the message, not the stack trace:
  puts e.backtrace
  $stderr.puts "error: #{e}"
end

==> glark-1.6.6.tar.gz: glark-1.6.6/glarkrun.rb <==
#!/bin/sh
exec ruby -w -x $0 ${1+"$@"} # -*- ruby -*-
#!ruby -w

# An extended grep, with extended functionality including full regular
# expressions, contextual output, highlighting, detection and exclusion of
# nontext files, and complex matching criteria.

# $Id: glarkrun.rb,v 1.12 2004/01/27 15:00:32 jeugenepace Exp $

require "English"

$stdout.sync = true             # unbuffer
$stderr.sync = true             # unbuffer

$PACKAGE = "glark"
$VERSION = "1.6.6"

require 'glarkfile'
require 'filetester'
require 'io'

# The main processor.
class Glark 
  include Loggable
  
  def initialize(func)
    @func = func
  end

  def search_file(fname, lines)
    log "searching #{fname} for #{@func}" if $options.verbose
    p = InputFile.new(fname, lines)
    @func.process(p)
  end

  def search_binary_file(fname, lines)
    log "searching binary file #{fname} for #{@func}" if $options.verbose
    bf = BinaryFile.new(fname, lines)
    @func.process(bf)
  end
  
  def search(name)
    log "searching #{name} for #{@func}"

    if name == "-" 
      log "reading standard input..."
      $stderr.print "reading standard input...\n" unless $options.quiet
      search_file(name, $stdin.readlines)
    else
      type = FileTester.type(name)
      case type
      when FileTester::TEXT
        log "searching text"
        # readlines doesn't work with $/ == nil, so we'll use gets instead
        # this has been fixed in Ruby (as of 26 Dec 2003)
        text = []
        File.open(name) do |f|
          while ((line = f.gets) && line.length > 0)
            log "got line #{line.length}"
            text << line
          end
        end
        log "got text #{text.length}"
        search_file(name, text)
      when FileTester::BINARY
        log "handling binary"
        # Log.print "not a text file: #{name}\n"
        
        case $options.binary_files
        when "without-match"
          log "skipping binary file #{name}"
          
        when "binary"
          search_binary_file(name, IO.readlines(name))
          
        when "text"
          log "processing binary file #{name} as text"
          search_file(name, IO.readlines(name))
        end
        
      when FileTester::UNREADABLE
        log "skipping unreadable"
        $stderr.print "file not readable: #{name}\n" unless $options.quiet
      when FileTester::NONE
        log "skipping none"
        $stderr.print "WARNING: no such file: #{name}\n" unless $options.quiet
      when FileTester::UNKNOWN
        log "skipping unknown"
        $stderr.print "WARNING: unknown file type: #{name}\n" unless $options.quiet
      when FileTester::DIRECTORY
        log "processing directory"
        case $options.directory
        when "read"
          log "directory: #{$options.directory}"
          $stderr.print "glark: #{name}: Is a directory\n" unless $options.quiet
        when "recurse"
          log "recursing into directory #{name}"
          entries = Dir.entries(name).reject { |x| x == "." || x == ".." }
          entries.each do |e|
            search(name + "/" + e)
          end
        when "skip"
          log "skipping directory #{name}"
        else
          log "directory: #{$options.directory}"
        end
      else
        print "unknown type #{type}"
      end
    end
  end
end

require 'glarkopt'

begin
  AppLog.set_widths(15, 5, -30)
  AppLog.set_color(Log::WARN, "reverse")

  AppLog.log "loading options"
  GlarkOptions.new($PACKAGE, $VERSION).run(ARGV)
  AppLog.log "done loading options"

  # To get rid of the annoying stack trace on ctrl-C:
  trap("INT") { abort }

  puts $options.expr.explain if $options.explain

  glark = Glark.new($options.expr)
  files = if ARGV.size > 0 then ARGV else [ '-' ] end

  files.each do |f|
    if $options.exclude_matching_files
      if $options.expr.evaluate(f, 0, 0)
        AppLog.log "skipping file #{f} with matching name"
        next
      else
        AppLog.log "not skipping file #{f}"
      end
    end
    glark.search(f) 
  end
rescue => e
  # show only the message, not the stack trace:
  $stderr.puts "error: #{e}"
  #$$$ only during debugging!
  #raise
end
